#!/bin/sh
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2008
###############################################################################
# 機能概要	:PRIMEQUESTの電源制御
# 実行形式	:pwrcntl.sh -h host_address -p pno {on | off}
# パラメタの説明:-h host_address
#                  管理対象PRIMEQUEST(MMB)のホスト名またはIPアドレスを指定
#                -p pno
#                  対象となるパーティションのパーティション番号を指定
#                on
#                  電源をONにする
#                off
#                  電源をOFFにする
###############################################################################
# 版数 修正日付   修正内容(下段に記述)
# 0001 2008/05/23 新規作成
###############################################################################

# 電源制御コマンドのパス
PWRCNTLCMD="/opt/FJSVpsmf/sbin/_psmf_pwrcntl"
# 自分の格納ディレクトリを取得
dir_path="$PWD"
# 電源制御コマンドのメッセージ出力格納ファイル名
OUTPUTFILE="pwrcntl.log"
# MMBホスト名およびパーティション番号の取得
mmb_add=$2
pno=$4
ope=$5

###############################################################################
# 言語変換処理
###############################################################################
# iconvコマンド
ICONVCMD="/usr/bin/iconv"
# エラーメッセージファイル名
ERRMSGFILE="pwrcntl_errmsg"
# LANG取得
mylang=$LANG
# OMGR動作環境変数
OMGRENV="BATCH"
# OMGR LANG設定ファイル
LANGENVFILENAME="/opt/systemwalker/etc/systemwalker.reg"
# LANG設定キーワード
LANGKEYWORD="^Code="
# iconv実行フラグ
iconv_flag=0
# 環境設定
ICONVUTF8="UTF-8"

# OMGRで動作しているかのチェック
isomgr=$JOBSCH_ENVIRONMENT
if [ "$isomgr" = "$OMGRENV" ]
then
	codeline=`grep "$LANGKEYWORD" "$LANGENVFILENAME"`
	codename=`echo "$codeline" | sed "s/$LANGKEYWORD//"`
	if [ "$codename" = "EUC" ]
	then
		TOICONV="EUC-JP-MS"
	fi
else
	if [ $mylang = "ja_JP" -o $mylang = "ja_JP.ujis" \
        -o $mylang = "ja_JP.eucJP" -o $mylang = "japanese.euc" ]
	then
		TOICONV="EUC-JP-MS"
	fi
fi

# 言語変換処理
if [ ! $mylang = "ja_JP.UTF-8" ]
then
	iconv_flag=1
	$ICONVCMD -f $ICONVUTF8 -t $TOICONV $dir_path/$ERRMSGFILE  > /tmp/FJSVoptm_errmsg
else
:
fi

# 3番のファイルディスクリプタを入力用に使用
if [ $iconv_flag -ne 0 ]
then
	exec 3< /tmp/FJSVoptm_errmsg
else
	exec 3< $dir_path/$ERRMSGFILE
fi

# 各行の入力を3番のファイルディスクリプタからもらう
while read i msg 0<&3
do
	eval ERRMSG$i='"$msg"'
done

# 一時ファイルを削除する
if [ $iconv_flag -ne 0 ]
then
:
	rm -f /tmp/FJSVoptm_errmsg
fi

# 3番のファイルディスクリプタを閉じる
exec 3<&-

###############################################################################
# main処理
###############################################################################

#_psmf_pwrcntlコマンドが存在するか確認
if [ ! -f "/opt/FJSVpsmf/sbin/_psmf_pwrcntl" ]; then
	echo $ERRMSG1
	exit 10
fi

# 電源制御コマンドを実行
date +'%y/%m/%d %H:%M:%S' >> "$dir_path/$OUTPUTFILE"
/opt/FJSVpsmf/sbin/_psmf_pwrcntl -h "$mmb_add" -p "$pno" "$ope" > /dev/null 2>> "$dir_path/$OUTPUTFILE" 

# 電源制御コマンドの復帰値を参照
if [ $? -ne 0 ]
then
	if [ "$ope" = "on" ]
	then
		echo $ERRMSG2
	else
		echo $ERRMSG3
	fi
	exit 1
fi

exit 0

